@@ -1,9 +1,6 @@
 import base64
 import logging
 
-import aiohttp
-
-
 log = logging.getLogger(__name__)
 
 
@@ -29,15 +26,3 @@ def encode(payload):
 
     encoded = base64.b64encode(payload)
     return encoded.replace(b'+', b'-').replace(b'/', b'_').decode('utf-8')
-
-
-async def raise_for_status(resp):
-    if resp.status >= 400:
-        try:
-            log.error(await resp.json())
-        except aiohttp.client_exceptions.ContentTypeError:
-            log.error(await resp.text())
-
-        raise aiohttp.client_exceptions.ClientResponseError(
-            resp.request_info, resp.history, code=resp.status,
-            headers=resp.headers, message=resp.reason)
